from pyxel import COLOR_LIME

AUTHOR = "Humberto Rocha"
AUTHOR_HANDLE = "@humrochagf"
EMAIL = "humrochagf@gmail.com"
VERSION = "1.4.0"

# Game screen

WIDTH = 192
HEIGHT = 192

# Game values

GRAVITY = 0.2
THRUSTERS_FORCE = 0.6
FUEL = 100

PERFECT_LANDING_LIMIT = 0.1
MAX_IMPACT_LIMIT = 0.3

PLATFORM_COLOR = COLOR_LIME
